@@ -79,7 +79,7 @@ func genGoDir(dir string, conf *Config, genTestPkg, recursively bool, flags GenF
 					if strings.HasPrefix(d.Name(), "_") { // skip _
 						return filepath.SkipDir
 					}
-					if e := genGoIn(path, conf, genTestPkg, flags); e != nil {
+					if e := genGoIn(path, conf, genTestPkg, flags); e != nil && notIgnNotated(e, conf) {
 						if flags&GenFlagPrintError != 0 {
 							fmt.Fprintln(os.Stderr, e)
 						}
@@ -106,13 +106,19 @@ func genGoDir(dir string, conf *Config, genTestPkg, recursively bool, flags GenF
 		}
 		return list.ToError()
 	}
-	err = genGoIn(dir, conf, genTestPkg, flags)
-	if err != nil && (flags&GenFlagPrintError) != 0 {
-		fmt.Fprintln(os.Stderr, err)
+	if e := genGoIn(dir, conf, genTestPkg, flags); e != nil && notIgnNotated(e, conf) {
+		if (flags & GenFlagPrintError) != 0 {
+			fmt.Fprintln(os.Stderr, e)
+		}
+		err = e
 	}
 	return
 }
 
+func notIgnNotated(e error, conf *Config) bool {
+	return !(conf != nil && conf.IgnoreNotatedError && IgnoreNotated(e))
+}
+
 func genGoEntry(list *errors.List, path string, d fs.DirEntry, conf *Config, flags GenFlags) error {
 	fname := d.Name()
 	if strings.HasPrefix(fname, "_") { // skip _
@@ -120,7 +126,7 @@ func genGoEntry(list *errors.List, path string, d fs.DirEntry, conf *Config, fla
 			return filepath.SkipDir
 		}
 	} else if !d.IsDir() && strings.HasSuffix(fname, ".gop") {
-		if e := genGoSingleFile(path, conf, flags); e != nil {
+		if e := genGoSingleFile(path, conf, flags); e != nil && notIgnNotated(e, conf) {
 			if flags&GenFlagPrintError != 0 {
 				fmt.Fprintln(os.Stderr, e)
 			}
@@ -134,9 +140,9 @@ func genGoSingleFile(file string, conf *Config, flags GenFlags) (err error) {
 	dir, fname := filepath.Split(file)
 	autogen := dir + strings.TrimSuffix(fname, ".gop") + "_augogen.go"
 	if (flags & GenFlagPrompt) != 0 {
-		fmt.Println("GenGo", file, "...")
+		fmt.Fprintln(os.Stderr, "GenGo", file, "...")
 	}
-	out, err := LoadFiles([]string{file}, nil)
+	out, err := LoadFiles([]string{file}, conf)
 	if err != nil {
 		return errors.NewWith(err, `LoadFiles(files, conf)`, -2, "gop.LoadFiles", file)
 	}
@@ -152,7 +158,7 @@ func genGoSingleFile(file string, conf *Config, flags GenFlags) (err error) {
 func genGoIn(dir string, conf *Config, genTestPkg bool, flags GenFlags, gen ...*bool) (err error) {
 	out, test, err := LoadDir(dir, conf, genTestPkg, (flags&GenFlagPrompt) != 0)
 	if err != nil {
-		if err == syscall.ENOENT { // no Go+ source files
+		if NotFound(err) { // no Go+ source files
 			return nil
 		}
 		return errors.NewWith(err, `LoadDir(dir, conf, genTestPkg)`, -5, "gop.LoadDir", dir, conf, genTestPkg)
